![Python package](https://github.com/jvanasco/metadata_utils/workflows/Python%20package/badge.svg)

metadata_utils
==============

This package offers lightweight tools for dealing with metadata in HTML.

The following functions are made available to streamline dealing with html encodings:

* `html_attribute_escape`
* `html_attribute_unescape`
* `force_clean_ascii_NFKD`
* `force_clean_ascii_NFKC`
